@@ -1,7 +1,7 @@
 # Global variables
 
-# ENVIRONMENT = 'development'
-ENVIRONMENT = 'production'
+ENVIRONMENT = 'development'
+# ENVIRONMENT = 'production'
 
 if ENVIRONMENT == 'production':
     HUB_API_ROOT = "https://api.ultralytics.com/"
